==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Інформація про PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Запущено інший процес розпізнавання. Спробуйте пізніше.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Розпізнавання не вдалося</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Чомусь розпізнавання не вдалося</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Помилка PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Вимагається розпізнавання</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation type="unfinished">Ідентифікатор:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="158"/>
        <source>PolicyKit Information</source>
        <translation>Інформація про PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Запущено інший процес розпізнавання. Спробуйте пізніше.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="139"/>
        <source>Authorization Failed</source>
        <translation>Розпізнавання не вдалося</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="139"/>
        <source>Authorization failed for some reason</source>
        <translation>Чомусь розпізнавання не вдалося</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="153"/>
        <source>PolicyKit Error</source>
        <translation>Помилка PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Вимагається розпізнавання</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Ідентифікатор:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
</TS>
